<?php

/**
 * Project of Engotheme.com
 * Author: EngoTheme
 */
class ENGOMetabox extends EngoFramework
{

	protected $pricing = array(
		'type' => 'engo_pricing',
		'name' => 'Pricing Table',
		'position' => 'normal',
	);
	protected $social = array(
		'type' => 'engo_social',
		'name' => 'Social Box',
		'position' => 'normal',
	);
	protected $detail_editor = array(
		'type' => 'engo_detail_editor',
		'name' => 'Detail',
		'position' => 'normal',
	);
	protected $offer = array(
		'type' => 'engo_offer',
		'name' => 'Offers',
		'position' => 'normal',
	);
	protected $feature = array(
		'type' => 'engo_feature',
		'name' => 'Features',
		'position' => 'normal',
	);
	protected $skill = array(
		'type' => 'engo_skill',
		'name' => 'Skills',
		'position' => 'normal',
	);
	protected $resume = array(
		'type' => 'engo_resume',
		'name' => 'Resume CV',
		'position' => 'normal',
	);
	protected $funfact = array(
		'type' => 'engo_funfact',
		'name' => 'Fun Fact',
		'position' => 'normal',
	);
	protected $format = array(
		'type' => 'engo_format',
		'name' => 'Format',
		'position' => 'side',
	);
	protected $client = array(
		'type' => 'engo_client',
		'name' => 'Client Information',
		'position' => 'normal',
	);
	protected $client_list = array(
		'type' => 'engo_client_list',
		'name' => 'Choose Client',
		'position' => 'side',
	);
	protected $total = array();

	public function __construct() {

		//loading script
		add_action( 'admin_enqueue_scripts', array( $this, 'loading_js' ) );
		add_action( 'admin_print_scripts', array( $this, 'print_js' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'loading_css' ) );
		//Add meta box created by

		add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
		// save service
		add_action( 'save_post', array( $this, 'meta_save' ), 100, 2 );
	}

	/**
	 * Loading Meta Box Css
	 */
	public function loading_css() {

		global $pagenow;
		if ( in_array( $pagenow, array( 'post.php', 'post-new.php' ) ) && is_admin() ) {
			foreach ( $this->total as $i ) {
				if ( $this->is_support( $i['type'] ) ) {
					wp_register_style( 'engo-metabox', ENGO_CSS_URL . 'metabox.css', false, '1.0.0' );
					wp_enqueue_style( 'engo-metabox' );
					if ( ! wp_style_is( 'engo-font-icon' ) ) {
						wp_register_style( 'engo-popup', ENGO_CSS_URL . 'popup.css', false, '1.0.0' );
						wp_enqueue_style( 'engo-popup' );
					}
				}
			}
		}
	}

	/**
	 * Loading Meta Box JS
	 */
	public function loading_js() {

		global $pagenow;
		if ( ENGO_DEBUG == true ) {
			$min = '.min'; } else {
			$min = ''; }
			$print = false;
			if ( in_array( $pagenow, array( 'post.php', 'post-new.php' ) ) && is_admin() ) {
				foreach ( $this->total as $i ) {

					if ( $this->is_support( $i['type'] ) && $print == false ) {
						wp_enqueue_script( 'engo-metabox', ENGO_JS_URL . 'metabox' . $min . '.js', array( 'jquery' ), null, false );
						$print = true;
					}
				}
			}
	}

	public function print_js() {

		global $pagenow;
		$print = false;
		if ( in_array( $pagenow, array( 'post.php', 'post-new.php' ) ) && is_admin() ) {
			foreach ( $this->total as $i ) {
				if ( $this->is_support( $i['type'] ) && $print == false ) {
					echo "<script>var ENGOURL = '" . ENGO_ROOT_URL . "';</script>";
					$print = true;
				}
			}
		}
	}

	/**
	 * Register meta box
	 * @param $post_type
	 */
	public function add_meta_box($post_type) {

		$screen = get_current_screen();
		if ( 'attraction' == $screen->id || 'page' == $screen->id ) {
			return; //Don't add feature image in attraction
		}
		foreach ( $this->total as $i ) {
			if ( $this->is_support( $i['type'] ) ) {
				add_meta_box( $i['type'], apply_filters( $i['type'] . '_title', $i['name'] ), array( $this, $i['type'] . '_html' ), $post_type, $i['position'], 'high' );
				add_filter( "postbox_classes_{$post_type}_{$i['type']}", array( $this, 'add_my_meta_box_classes' ) );
			}
		}
	}

	/**
	 * Add engo-settings class into wrap
	 * @param array $classes
	 *
	 * @return array
	 */
	public function add_my_meta_box_classes($classes = array()) {

		/* In order to ensure we don't duplicate classes, we should
          check to make sure it's not already in the array */
		if ( ! in_array( 'engo-settings', $classes ) ) {
			$classes[] = 'engo-settings'; }

		return $classes;
	}

	public function engo_client_list_html() {

		if ( ! $this->is_support( $this->client_list['type'] ) ) {
			return; }
		wp_nonce_field( $this->client_list['type'] . '_save', $this->client_list['type'] . '_nonce' );
		$value = $this->get_custom_fields( 'client_list', array() );
		$value = ( ! empty( $value )) ? $value : 'none';
		$posts = get_posts( array( 'post_type' => 'engo_client' ) );
		if ( ! is_array( $posts ) || count( $posts ) < 0 ) {
			_e( 'You have to create client first!', 'lotus' );
			return;
		} else {
			?>
            <div class="engo-client-list">
                <select name="<?php echo esc_attr( $this->client_list['type'] . '[client_list]' ); ?>">
                    <option <?php selected( $value, 'none' ); ?> value="none"><?php _e( 'Private', 'lotus' ); ?></option>
                    <?php foreach ( $posts as $post ) :   ?>

                        <option <?php selected( $value, $post->ID ); ?>
                            value="<?php echo esc_attr( $post->ID ); ?>"><?php echo wp_unslash( $post->post_title ); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
        <?php
		}
	}

	/**
	 * Generate Client Info
	 */
	public function engo_client_html() {

		if ( ! $this->is_support( $this->client['type'] ) ) {
			return; }
		wp_nonce_field( $this->client['type'] . '_save', $this->client['type'] . '_nonce' );
		$values = $this->get_custom_fields( 'client', array() );
		$values['logo'] = (isset( $values['logo'] )) ? $values['logo'] : ENGO_ROOT_URL . 'asset/images/logo.png';
		$values['url'] = (isset( $values['url'] )) ? $values['url'] : '#';
		?>
        <div class="engo-client">
            <div class="client-url">
                <label id="client-url"><?php _e( 'Url', 'lotus' ); ?></label>
                <input type="text" id="client-url" class="medium client-url"
                       value="<?php echo esc_url( $values['url'] ); ?>"
                       name="<?php echo esc_attr( $this->client['type'] . '[client][url]' ); ?>">
            </div>
            <div class="client-logo">
                <label id="client-logo"><?php _e( 'Logo', 'lotus' ); ?></label>
                <a href="#" class="photo"><img src="<?php echo esc_url( $values['logo'] ); ?>"></a>
                <input type="hidden" id="client-logo" class="input-photo"
                       value="<?php echo esc_url( $values['logo'] ); ?>"
                       name="<?php echo esc_attr( $this->client['type'] ) . '[client][logo]'; ?>">
            </div>
        </div>
    <?php
	}

	/**
	 * Generate Format Posts Type
	 */
	public function engo_format_html() {

		if ( ! $this->is_support( $this->format['type'] ) ) {
			return; }

		$types = array(
			'standard' => 'Standard',
			'gallery' => 'Gallery',
			'audio' => 'Audio',
			'link' => 'Link',
			'video' => 'Video',
			'image' => 'Image',
			'quote' => 'Quote',
		);
		$formats = apply_filters( 'engo_format_types', $types );
		wp_nonce_field( $this->format['type'] . '_save', $this->format['type'] . '_nonce' );
		$value = $this->get_custom_fields( 'format', array( 'format' => 'standard' ) );
		?>
        <div id="post-formats-select">
            <?php foreach ( $formats as $key => $name ) :   ?>
                <input type="radio" <?php checked( $value, $key ); ?> value="<?php echo esc_attr( $key ); ?>"
                       id="post-format-<?php echo esc_attr( $key ); ?>" class="post-format"
                       name="<?php echo esc_attr( $this->format['type'] . '[format]' ); ?>"> <label
                    class="post-format-icon post-format-<?php echo esc_attr( $key ); ?>"
                    for="post-format-<?php echo esc_attr( $key ); ?>"><?php echo wp_unslash( $name ); ?></label>
                <br>
            <?php endforeach; ?>
        </div>
    <?php
	}

	/**
	 * Generate Pricing Table
	 */
	public function engo_pricing_html() {

		if ( ! $this->is_support( $this->pricing['type'] ) ) {
			return; }
		wp_nonce_field( $this->pricing['type'] . '_save', $this->pricing['type'] . '_nonce' );
		$items = $this->get_custom_fields( 'pricing', array() );

		if ( $items ) {
			$items = json_decode( $items ); }
		?>
        <div class="engo-pricing">
            <ul id="pricing-sortable">
                <?php
				if ( is_array( $items ) ) :
					foreach ( $items as $item ) :
						?>
                        <li>
                            <div class="engo-pricing-price">
                                <label><?php _e( 'Price', 'lotus' ); ?></label>
                                <input type="text" class="pricing-price" value="<?php echo esc_attr( $item->price ); ?>">
                            </div>
                            <div class="engo-pricing-currency">
                                <label><?php _e( 'Currency', 'lotus' ); ?></label>
                                <input type="text" class="pricing-currency"
                                       value="<?php echo esc_attr( $item->currency ); ?>" placeholder="$">
                            </div>
                            <div class="engo-pricing-duration">
                                <label><?php _e( 'Duration', 'lotus' ); ?></label>
                                <input type="text" class="pricing-duration"
                                       value="<?php echo esc_attr( $item->duration ); ?>" placeholder="month">
                            </div>
                            <div class="engo-pricing-title">
                                <label><?php _e( 'Title', 'lotus' ); ?></label>
                                <input type="text" class="pricing-title" value="<?php echo esc_attr( $item->title ); ?>">
                            </div>
                            <div class="engo-pricing-desc">
                                <label><?php _e( 'Description', 'lotus' ); ?></label>
                                <input type="text" class="pricing-desc" value="<?php echo esc_attr( $item->desc ); ?>">
                            </div>
                            <div class="engo-pricing-offer">
                                <label><?php _e( 'Offers', 'lotus' ); ?></label>

                                <div class="engo-pricing-offer-items">
                                    <?php if ( is_array( $item->offers ) ) :   ?>
                                        <?php foreach ( $item->offers as $offer ) :   ?>
                                            <div class="engo-pricing-offer-item">
                                                <input type="text" class="pricing-offer-item"
                                                       value="<?php echo esc_attr( $offer ); ?>">
                                                <a href="#" class="pricing-offer-remove fa fa-trash-o"></a>
                                            </div>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </div>
                                <input type="button" class="add-offer pricing-offer-add" value="Add Offer">
                            </div>
                            <div class="engo-pricing-url">
                                <label><?php _e( 'Url', 'lotus' ); ?></label>
                                <input type="text" class="pricing-url" value="<?php echo esc_url( $item->url ); ?>">
                            </div>
                            <div class="engo-pricing-remove">
                                <a href="#"
                                   class="pricing-button pricing-item-remove"><?php _e( 'Remove', 'lotus' ); ?></a>
                                <a href="#"
                                   class="pricing-button pricing-item-clone"><?php _e( 'Clone', 'lotus' ); ?></a>
                            </div>
                        </li>
                    <?php
					endforeach;
				endif;
				?>
            </ul>

        </div>
        <div class="engo-pricing-addmore">
            <input type="hidden" class="pricing-value"
                   name="<?php echo esc_attr( $this->pricing['type'] ) . '[pricing]'; ?>"
                   value='<?php echo json_encode( $items ); ?>'>
            <input type="button" value="Add More" class="button button-primary button-large pricing-add-more">
            <li style="display: none" class="clone">
                <div class="engo-pricing-price">
                    <label><?php _e( 'Price', 'lotus' ); ?></label>
                    <input type="text" class="pricing-price">
                </div>
                <div class="engo-pricing-currency">
                    <label><?php _e( 'Currency', 'lotus' ); ?></label>
                    <input type="text" class="pricing-currency" placeholder="$">
                </div>
                <div class="engo-pricing-duration">
                    <label><?php _e( 'Duration', 'lotus' ); ?></label>
                    <input type="text" class="pricing-duration" placeholder="month">
                </div>
                <div class="engo-pricing-title">
                    <label><?php _e( 'Title', 'lotus' ); ?></label>
                    <input type="text" class="pricing-title">
                </div>
                <div class="engo-pricing-desc">
                    <label><?php _e( 'Description', 'lotus' ); ?></label>
                    <input type="text" class="pricing-desc">
                </div>
                <div class="engo-pricing-offer">
                    <label><?php _e( 'Offers', 'lotus' ); ?></label>

                    <div class="engo-pricing-offer-items">
                        <div class="engo-pricing-offer-item">
                            <input type="text" class="pricing-offer-item">
                            <a href="#" class="pricing-offer-remove  fa fa-trash-o"></a>
                        </div>
                    </div>
                    <input type="button" class="add-offer pricing-offer-add" value="Add Offer">
                </div>
                <div class="engo-pricing-url">
                    <label><?php _e( 'Url Button', 'lotus' ); ?></label>
                    <input type="text" class="pricing-url">
                </div>
                <div class="engo-pricing-remove">
                    <a href="#" class="pricing-button pricing-item-remove"><?php _e( 'Remove', 'lotus' ); ?></a>
                    <a href="#" class="pricing-button pricing-item-clone"><?php _e( 'Clone', 'lotus' ); ?></a>
                </div>
            </li>
        </div>
    <?php
	}

	/**
	 * Gererate Social Box
	 */
	public function engo_social_html() {

		if ( ! $this->is_support( $this->social['type'] ) ) {
			return; }
		wp_nonce_field( $this->social['type'] . '_save', $this->social['type'] . '_nonce' );
		$social = array(
			'facebook' => 'fa fa-facebook',
			'google' => 'fa fa-google-plus',
			'twitter' => 'fa fa-twitter',
			'github' => 'fa fa-github-alt',
			'instagram' => 'fa fa-instagram',
			'pinterest' => 'fa fa-pinterest',
			'linkedin' => 'fa fa-linkedin',
			'skype' => 'fa fa-skype',
			'tumblr' => 'fa fa-tumblr',
			'youtube' => 'fa fa-youtube',
			'vimeo' => 'fa fa-vimeo-square',
			'dribbble' => 'fa fa-dribbble',
		);
		$social = apply_filters( $this->social['type'] . '_fields', $social );
		$default = array();
		?>
        <div class="engo-social">
            <ul>
                <?php $values = $this->get_custom_fields( 'social', array() ); ?>
                <?php foreach ( $social as $type => $icon ) :   ?>
                    <?php $value = (isset( $values[$type] )) ? $values[$type] : ''; ?>
                    <li>
                        <label for="<?php echo esc_attr( $type ); ?>"><i
                                class="fa <?php echo esc_attr( $icon ); ?>"></i></label>
                        <input type="text" class="medium" value="<?php echo esc_attr( $value ); ?>"
                               id="<?php echo esc_attr( $type ); ?>" size="30"
                               name="<?php echo esc_attr( $this->social['type'] . '[social][' . $type . ']' ); ?>">
                    </li>
                <?php endforeach; ?>
            </ul>
        </div>

    <?php
	}

	/**
	 * Generate Detail Editor base on Wp Editor
	 */
	public function engo_detail_editor_html() {

		if ( ! $this->is_support( $this->detail_editor['type'] ) ) {
			return; }
		wp_nonce_field( $this->detail_editor['type'] . '_save', $this->detail_editor['type'] . '_nonce' );
		$default = array( 'detail' => '' );
		$value = $this->get_custom_fields( 'detail', $default );
		wp_editor( htmlspecialchars_decode( $value ), $this->detail_editor['type'] . 'detail', $settings = array( 'textarea_name' => $this->detail_editor['type'] . '[detail]', 'textarea_rows' => '5', 'media_buttons' => true, 'tinymce' => true ) );
	}

	/**
	 * Generate Offer Options
	 */
	public function engo_offer_html() {

		if ( ! $this->is_support( $this->offer['type'] ) ) {
			return; }
		wp_nonce_field( $this->offer['type'] . '_save', $this->offer['type'] . '_nonce' );
		$value = $this->get_custom_fields( 'offer', false );
		?>
        <div class="engo-offer">
            <div class="engo-offer-fields">
                <?php if ( is_array( $value ) && count( $value ) > 0 ) :   ?>
                    <?php foreach ( $value as $i ) :   ?>
                        <div class="offer-item"><input name="<?php echo esc_attr( $this->offer['type'] ) ?>[offer][]"
                                                       class="medium" type="text" value="<?php echo esc_attr( $i ); ?>"><a
                                href="#" class="remove-offer">Delete</a></div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <div class="offer-item"><input name="<?php echo esc_attr( $this->offer['type'] ) ?>[offer][])"
                                                   class="medium" type="text" value=""><a href="#" class="remove-offer">Delete</a>
                    </div>
                <?php endif; ?>

            </div>
            <div class="engo-offer-price-show">
                <input type="checkbox" id="show-price" value="1"
                       name="<?php echo esc_attr( $this->offer['type'] ) ?>[offer_show_price]" <?php checked( $this->get_custom_fields( 'offer_show_price', false ), 1 ) ?>>
                <label for="show-price"><?php _e( 'Display Price', 'lotus' ); ?></label>
            </div>
            <div
                class="engo-offer-price" <?php if ( $this->get_custom_fields( 'offer_show_price', false ) == 0 ) :   ?> style="display: none"<?php endif; ?>>
                <input type="text" name="<?php echo esc_attr( $this->offer['type'] ) ?>[offer_price]" class="medium"
                       type="text" value="<?php echo esc_attr( $this->get_custom_fields( 'offer_price', false ) ); ?>"
                       placeholder="Pricing">$
            </div>
            <input type="button" class="button button-primary button-large offer-add-more" value="Add More">
        </div>
    <?php
	}

	/**
	 * Generate Features Options
	 */
	public function engo_feature_html() {

		if ( ! $this->is_support( $this->feature['type'] ) ) {
			return; }
		wp_nonce_field( $this->feature['type'] . '_save', $this->feature['type'] . '_nonce' );
		?>
        <div class="engo-feature">
            <div class="engo-feature-all-items clearfix">
                <?php
				$count = 0;
				$features = $this->get_custom_fields( 'features', array() );
				?>
                <?php if ( is_array( $features ) && count( $features ) > 0 ) :   ?>
                    <?php foreach ( $features as $num => $value ) :   ?>
                        <?php $count++; ?>
                        <div class="engo-feature-item" num="<?php echo esc_attr( $num ); ?>">
                            <div class="engo-feature-left">
                                <div class="engo-feature-logo-option">
                                    <input type="radio"
                                           name="<?php echo esc_attr( $this->feature['type'] ) ?>[features][<?php echo esc_attr( $num ); ?>][logo_type]"
                                           value="none" <?php checked( $value['logo_type'], 'none' ); ?>> None
                                    <input type="radio"
                                           name="<?php echo esc_attr( $this->feature['type'] ) ?>[features][<?php echo esc_attr( $num ); ?>][logo_type]"
                                           value="icon" <?php checked( $value['logo_type'], 'icon' ); ?>> Icon
                                    <input type="radio"
                                           name="<?php echo esc_attr( $this->feature['type'] ) ?>[features][<?php echo esc_attr( $num ); ?>][logo_type]"
                                           value="image" <?php checked( $value['logo_type'], 'image' ); ?>> Image
                                </div>
                                <div class="engo-feature-logo-preview">
                                    <div
                                        class="engo-feature-logo-none" <?php if ( $value['logo_type'] != 'none' ) :   ?> style="display: none"<?php endif; ?>>
                                        none
                                    </div>
                                    <div
                                        class="engo-feature-logo-icon" <?php if ( $value['logo_type'] != 'icon' ) :   ?> style="display: none"<?php endif; ?>>
                                        <a href="#" class="choose-icon"><i
                                                class="<?php echo esc_attr( $value['logo_icon'] ); ?>"></i></a>
                                        <input type="hidden" class="input-icon skill-icon"
                                               value="<?php echo esc_attr( $value['logo_icon'] ); ?>"
                                               name="<?php echo esc_attr( $this->feature['type'] ) ?>[features][<?php echo esc_attr( $num ); ?>][logo_icon]">
                                    </div>
                                    <div
                                        class="engo-feature-logo-image" <?php if ( $value['logo_type'] != 'image' ) :   ?> style="display: none"<?php endif; ?>>
                                        <a href="#" class="photo"><img src="<?php echo esc_url( $value['logo_img'] ); ?>"></a>
                                        <input type="hidden" class="input-photo" id="position"
                                               value="<?php echo esc_url( $value['logo_img'] ); ?>"
                                               name="<?php echo esc_attr( $this->feature['type'] ); ?>[features][<?php echo esc_attr( $num ); ?>][logo_img]">
                                    </div>
                                </div>
                            </div>

                            <div class="engo-feature-right">
                                <div class="engo-feature-title">
                                    <input class="medium" placeholder="Feature Name" type="text"
                                           name="<?php echo esc_attr( $this->feature['type'] ); ?>[features][<?php echo esc_attr( $num ); ?>][title]"
                                           value="<?php echo esc_attr( $value['title'] ); ?>">
                                </div>
                                <div class="engo-feature-desc">
                                    <textarea class="medium" placeholder="Feature Description"
                                              name="<?php echo esc_attr( $this->feature['type'] ); ?>[features][<?php echo esc_attr( $num ); ?>][desc]"><?php echo esc_textarea( $value['desc'] ); ?></textarea>
                                </div>
                                <div class="engo-feature-link-url">
                                    <?php $value['link']['url'] = (isset( $value['link']['url'] )) ? $value['link']['url'] : '#'; ?>
                                    <input class="medium" placeholder="#" type="text"
                                           name="<?php echo esc_attr( $this->feature['type'] ); ?>[features][<?php echo esc_attr( $num ); ?>][link][url]"
                                           value="<?php echo esc_attr( $value['link']['url'] ); ?>">
                                </div>
                                <div class="engo-feature-link-title">
                                    <?php $value['link']['title'] = (isset( $value['link']['title'] )) ? $value['link']['title'] : ''; ?>
                                    <input class="medium" placeholder="Link Title" type="text"
                                           name="<?php echo esc_attr( $this->feature['type'] ); ?>[features][<?php echo esc_attr( $num ); ?>][link][title]"
                                           value="<?php echo esc_attr( $value['link']['title'] ); ?>">
                                </div>
                            </div>

                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>

            </div>
            <div class="engo-feature-item feature-clone" feature-name="<?php echo esc_attr( $this->feature['type'] ); ?>"
                 style="display: none">
                <div class="engo-feature-left">
                    <div class="engo-feature-logo-option">
                        <input type="radio" name="" value="none" checked="checked"> None
                        <input type="radio" name="" value="icon"> Icon
                        <input type="radio" name="" value="image"> Image
                    </div>
                    <div class="engo-feature-logo-preview">
                        <div class="engo-feature-logo-none">
                            none
                        </div>
                        <div class="engo-feature-logo-icon" style="display: none">
                            <a href="#" class="choose-icon"><i class="fa fa-facebook-square"></i></a>
                            <input type="hidden" class="input-icon" value="fa fa-facebook-square" name="">
                        </div>
                        <div class="engo-feature-logo-image" style="display: none">
                            <a href="#" class="photo"><img
                                    src="<?php echo esc_url( ENGO_ROOT_URL . 'asset/images/logo2.jpg' ); ?>"></a>
                            <input type="hidden" class="input-photo" id="position"
                                   value="<?php echo esc_url( ENGO_ROOT_URL . 'asset/images/logo2.jpg' ); ?>" name="">
                        </div>
                    </div>
                </div>

                <div class="engo-feature-right">
                    <div class="engo-feature-title">
                        <input class="medium" placeholder=" Feature Name" type="text" size="20" name="">
                    </div>
                    <div class="engo-feature-desc">
                        <textarea class="medium" name="" placeholder="Feature Description"></textarea>
                    </div>
                    <div class="engo-feature-link-url">
                        <input class="medium" placeholder="#" type="text" size="20" name="">
                    </div>
                    <div class="engo-feature-link-title">
                        <input class="medium" placeholder="Link Title" type="text" size="20" name="">
                    </div>
                </div>
            </div>
            <input type="button" class="button button-primary button-large feature-add-more" value="Add More">
        </div>


    <?php
	}

	/**
	 * Generate Skills Options
	 */
	public function engo_skill_html() {

		if ( ! $this->is_support( $this->skill['type'] ) ) {
			return; }
		wp_nonce_field( $this->skill['type'] . '_save', $this->skill['type'] . '_nonce' );
		?>
        <div class="engo-skills">
            <?php $skills = $this->get_custom_fields( 'skills', array() ); ?>
            <div class="all-skills">
                <?php $count = 0; ?>
                <?php if ( is_array( $skills ) && count( $skills ) > 0 ) :   ?>
                    <?php foreach ( $skills as $num => $value ) :   ?>
                        <?php $count++; ?>
                        <div class="skill-item" num="<?php echo esc_attr( $num ); ?>">
                            <!-- <a href="#" class="choose-icon"><i class="<?php //echo esc_attr($value['icon']);      ?>"></i></a> -->
                            <input type="hidden" class="input-icon skill-icon"
                                   value="<?php echo esc_attr( $value['icon'] ); ?>"
                                   name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][<?php echo esc_attr( $num ); ?>][icon]">

                            <!-- Skill Range -->
                            <div class="skill-custom">
                                <div class="piechart">
                                    <span data-percent="<?php echo esc_attr( $value['pro'] ); ?>" class="chart">
                                        <span class="percent"><?php echo esc_attr( $value['pro'] ); ?></span>
                                    </span>
                                </div>
                                <div class="skill-range"></div>
                            </div>

                            <input type="hidden" class="skill-pro" value="<?php echo esc_attr( $value['pro'] ); ?>"
                                   name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][<?php echo esc_attr( $num ); ?>][pro]"
                                   placeholder="<?php _e( 'Professional (%)', 'lotus' ); ?>">
                            <?php $show_title = apply_filters( 'metabox_skill_show_title', true ); ?>
                            <?php if ( ! $show_title ) :   ?>
                            <div style="display: none"><?php endif; ?>
                                <input type="text" class="small skill-name"
                                       value="<?php echo esc_attr( $value['name'] ); ?>"
                                       name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][<?php echo esc_attr( $num ); ?>][name]"
                                       placeholder="<?php _e( 'Skill name', 'lotus' ); ?>">
                                <?php if ( ! $show_title ) :   ?></div><?php endif; ?>
                            <?php $show_desc = apply_filters( 'metabox_skill_show_desc', true ); ?>
                            <?php if ( ! $show_desc ) :   ?>
                            <div style="display: none"><?php endif; ?>
                                <input type="text" class="medium skill-desc"
                                       value="<?php echo esc_attr( $value['desc'] ); ?>"
                                       name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][<?php echo esc_attr( $num ); ?>][desc]"
                                       placeholder="<?php _e( 'Skill description', 'lotus' ); ?>">
                                <?php if ( ! $show_desc ) :   ?></div><?php endif; ?>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <div class="skill-item" num="1">
                        <!-- <a href="#" class="choose-icon"><i class="fa fa-html5"></i></a> -->
                        <!-- <a class="choose-icon" href="#"><i class="fa fa-html5"></i></a> -->

                        <!-- Skill Range -->
                        <div class="skill-custom">
                            <div class="piechart">
                                <span data-percent="0" class="chart">
                                    <span class="percent">0</span>
                                </span>
                            </div>
                            <div class="skill-range"></div>
                        </div>

                        <input type="hidden" class="input-icon skill-icon" value="fa fa-html5"
                               name="--><?php echo esc_attr( $this->skill['type'] ); ?>[skills][1][icon]">
                        <input type="hidden" class="skill-pro" value=""
                               name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][1][pro]"
                               placeholder="<?php _e( 'Professional (%)', 'lotus' ); ?>">
                        <?php $show_title = apply_filters( 'metabox_skill_show_title', true ); ?>
                        <?php if ( ! $show_title ) :   ?>
                        <div style="display: none"><?php endif; ?>
                            <input type="text" class="small skill-name" value=""
                                   name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][1][name]"
                                   placeholder="<?php _e( 'Skill name', 'lotus' ); ?>">
                            <?php if ( ! $show_title ) :   ?></div><?php endif; ?>
                        <?php $show_desc = apply_filters( 'metabox_skill_show_desc', true ); ?>
                        <?php if ( ! $show_desc ) :   ?>
                        <div style="display: none"><?php endif; ?>
                            <input type="text" class="medium skill-desc" value=""
                                   name="<?php echo esc_attr( $this->skill['type'] ); ?>[skills][1][desc]"
                                   placeholder="<?php _e( 'Skill description', 'lotus' ); ?>">
                            <?php if ( ! $show_desc ) :   ?></div><?php endif; ?>
                    </div>
                <?php endif; ?>
                <?php $count++; ?>
                <div class="clear"></div>
            </div>
            <div class="addmore-action">
                <div class="skill-item skill-clone" num="" style="display:none"
                     skill-name="<?php echo esc_attr( $this->skill['type'] ); ?>">
                    <!-- Skill Range -->
                    <div class="skill-custom">
                        <div class="piechart">
                            <span data-percent="0" class="chart">
                                <span class="percent">0</span>
                            </span>
                        </div>
                        <div class="skill-range"></div>
                    </div>

                    <input type="hidden" name="" value="fa fa-html5" class="input-icon">
                    <input type="hidden" placeholder="<?php _e( 'Professional (%)', 'lotus' ); ?>" name="" value=""
                           class="skill-pro" type="text">
                    <?php $show_title = apply_filters( 'metabox_skill_show_title', true ); ?>
                    <?php if ( ! $show_title ) :   ?>
                    <div style="display: none"><?php endif; ?>
                        <input placeholder="<?php _e( 'Skill name', 'lotus' ); ?>" name="" value=""
                               class="small skill-name" type="text">
                        <?php if ( ! $show_title ) :   ?></div><?php endif; ?>
                    <?php $show_desc = apply_filters( 'metabox_skill_show_desc', true ); ?>
                    <?php if ( ! $show_desc ) :   ?>
                    <div style="display: none"><?php endif; ?>
                        <input placeholder="<?php _e( 'Skill description', 'lotus' ); ?>" name="" value=""
                               class="medium skill-desc" type="text">
                        <?php if ( ! $show_desc ) :   ?></div><?php endif; ?>
                </div>
                <input type="button" class="button button-primary button-large skill-add-more" value="Add more">
            </div>
        </div>
    <?php
	}

	/** Generate Fun Fact Html */
	public function engo_funfact_html() {

		if ( ! $this->is_support( $this->funfact['type'] ) ) {
			return; }
		wp_nonce_field( $this->funfact['type'] . '_save', $this->funfact['type'] . '_nonce' );
		?>
        <div class="engo-funfacts">
            <?php $funfacts = $this->get_custom_fields( 'funfacts', array() ); ?>
            <div class="all-funfacts">
                <?php $count = 0; ?>
                <?php if ( is_array( $funfacts ) && count( $funfacts ) > 0 ) :   ?>
                    <?php foreach ( $funfacts as $num => $value ) :   ?>
                        <?php $count++; ?>
                        <div class="funfact-item" num="<?php echo esc_attr( $num ); ?>">
                            <div class="funfact-item-inner">
                                <a href="#" class="choose-icon"><i class="<?php echo esc_attr( $value['icon'] ); ?>"></i></a>
                                <input type="hidden" class="input-icon" value="<?php echo esc_attr( $value['icon'] ); ?>"
                                       name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][<?php echo esc_attr( $num ); ?>][icon]">
                                <input class="small funfact-total" placeholder="Ex: any numbers..." type="text"
                                       value="<?php echo esc_attr( $value['total'] ); ?>"
                                       name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][<?php echo esc_attr( $num ); ?>][total]"
                                       placeholder="<?php _e( 'Total', 'lotus' ); ?>">
                                <input class="medium funfact-title" placeholder="Ex: project, client,..." type="text"
                                       value="<?php echo esc_attr( $value['name'] ); ?>"
                                       name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][<?php echo esc_attr( $num ); ?>][name]"
                                       placeholder="<?php _e( 'Title', 'lotus' ); ?>">
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php else : ?>
                    <div class="funfact-item" num="1">
                        <div class="funfact-item-inner">
                            <a href="#" class="choose-icon"><i class="fa fa-html5"></i></a>
                            <input type="hidden" class="input-icon" value="fa fa-html5"
                                   name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][1][icon]">
                            <input class="small funfact-total" placeholder="Ex: any numbers..." type="text" type="text"
                                   value="" name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][1][total]"
                                   placeholder="<?php _e( 'Total', 'lotus' ); ?>">
                            <input class="medium funfact-title" placeholder="Ex: project, client,..." type="text"
                                   value="" name="<?php echo esc_attr( $this->funfact['type'] ); ?>[funfacts][1][name]"
                                   placeholder="<?php _e( 'Title', 'lotus' ); ?>">
                        </div>
                    </div>
                <?php endif; ?>
            </div>
            <div class="addmore-action">
                <div class="funfact-item funfact-clone" num="" style="display:none"
                     funfact-name="<?php echo esc_attr( $this->funfact['type'] ); ?>">
                    <div class="funfact-item-inner">
                        <a class="choose-icon" href="#"><i class="fa fa-html5"></i></a>
                        <input type="hidden" name="" value="fa fa-html5" class="input-icon">
                        <input type="text" name="" value="" class="small funfact-total"
                               placeholder="Ex: any numbers...">
                        <input type="text" name="" value="" class="medium funfact-title"
                               placeholder="Ex: project, client,...">
                    </div>
                </div>
                <!-- Button Add More -->
                <input type="button" class="button button-primary button-large funfact-add-more" value="Add more">
            </div>
        </div>
    <?php
	}

	/**
	 * Generate Resume CV Profile HTML
	 */
	public function engo_resume_html() {

		if ( ! $this->is_support( $this->resume['type'] ) ) {
			return; }
		wp_nonce_field( $this->resume['type'] . '_save', $this->resume['type'] . '_nonce' );
		?>
        <div class="engo-resume">
            <?php $items = $this->get_custom_fields( 'resumes', array() ); ?>
            <div class="engo-resume-all-items">
                <div class="engo-resume-download">
                    <label>Link Download Resume
                        <input class="big" type="text"
                               placeholder="<?php _e( 'Enter your Resume CV url', 'lotus' ); ?>"
                               name="<?php echo esc_attr( $this->resume['type'] ); ?>[resume_url]"
                               value="<?php echo esc_url( $this->get_custom_fields( 'resume_url', false ) ); ?>">
                        <input type="button" value="Upload" class="button button-large upload-resume">
                    </label>
                </div>
                <?php $count = 0; ?>
                <?php if ( is_array( $items ) && count( $items ) > 0 ) :   ?>

                    <?php foreach ( $items as $num => $value ) :   ?>
                        <?php $count++; ?>
                        <!-- Resume Item -->
                        <div class="engo-resume-item" num="<?php echo esc_attr( $count ); ?>">
                            <div class="engo-resume-item-left">
                                <div class="engo-resume-item-time">
                                    <input class="mini" type="text" size="30" class="resume-time"
                                           name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][<?php echo esc_attr( $num ); ?>][time]"
                                           value="<?php echo esc_attr( $value['time'] ); ?>" placeholder="Prior time">
                                </div>
                                <div class="engo-resume-item-type">
                                    <select
                                        name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][<?php echo esc_attr( $num ); ?>][type]"
                                        class="resume-type">
                                        <option <?php selected( $value['type'], 'work' ); ?> value="work">Work</option>
                                        <option <?php selected( $value['type'], 'education' ); ?> value="education">
                                            Eduction
                                        </option>
                                    </select>
                                </div>
                            </div>
                            <div class="engo-resume-item-right">
                                <div class="engo-resume-item-title">
                                    <input class="medium" type="text" size="30" class="resume-title"
                                           name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][<?php echo esc_attr( $num ); ?>][title]"
                                           placeholder="Title" value="<?php echo esc_attr( $value['title'] ); ?>">
                                </div>
                                <div class="engo-resume-item-position">
                                    <input class="small" type="text" size="30" class="resume-position"
                                           name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][<?php echo esc_attr( $num ); ?>][position]"
                                           value="<?php echo esc_attr( $value['position'] ); ?>" placeholder="Position">
                                </div>
                                <div class="engo-resume-item-desc">
                                    <textarea
                                        name="<?php echo esc_attr( $this->resume['type'] ) . '[resumes][' . $num . '][desc]'; ?>"
                                        class="resume-desc"
                                        placeholder="Writing an introduction, here ..."><?php echo esc_textarea( $value['desc'] ); ?></textarea>
                                </div>
                            </div>
                            <div class="clear"></div>
                        </div>
                        <!-- End Resume Item -->
                    <?php endforeach; ?>
                <?php else : ?>

                    <div class="engo-resume-item" num="1">
                        <div class="engo-resume-item-left">
                            <div class="engo-resume-item-time">
                                <input class="mini" type="text" size="30" class="resume-time"
                                       name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][1][time]"
                                       placeholder="Prior time">
                            </div>
                            <div class="engo-resume-item-type">
                                <select name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][1][type]"
                                        class="resume-type">
                                    <option value="work">Work</option>
                                    <option value="education">Eduction</option>
                                </select>
                            </div>
                        </div>
                        <div class="engo-resume-item-right">
                            <div class="engo-resume-item-title">
                                <input class="medium" type="text" size="30" class="resume-title"
                                       name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][1][title]"
                                       placeholder="Title">
                            </div>
                            <div class="engo-resume-item-position">
                                <input class="small" type="text" size="30" class="resume-position"
                                       name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][1][position]"
                                       placeholder="Position">
                            </div>
                            <div class="engo-resume-item-desc">
                                <textarea class="resume-desc"
                                          name="<?php echo esc_attr( $this->resume['type'] ); ?>[resumes][1][desc]"
                                          placeholder="Writing an introduction, here ..."></textarea>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

            </div>
            <div class="addmore-action">
                <div class="engo-resume-item resume-clone" resume-name="<?php echo esc_attr( $this->resume['type'] ); ?>"
                     num="" style="display: none">
                    <div class="engo-resume-item-left">
                        <div class="engo-resume-item-time">
                            <input class="mini resume-time" type="text" size="30" class="resume-time" name=""
                                   placeholder="Prior time">
                        </div>
                        <div class="engo-resume-item-type">
                            <select name="" class="resume-type">
                                <option value="work">Work</option>
                                <option value="education">Education</option>
                            </select>
                        </div>
                    </div>
                    <div class="engo-resume-item-right">
                        <div class="engo-resume-item-title">
                            <input class="medium resume-title" type="text" size="30" class="resume-title" name=""
                                   placeholder="Title">
                        </div>
                        <div class="engo-resume-item-position">
                            <input class="small resume-position" type="text" size="30" class="resume-position" name=""
                                   placeholder="Position">
                        </div>
                        <div class="engo-resume-item-desc">
                            <textarea class="resume-desc" name=""
                                      placeholder="Writing an introduction, here ..."></textarea>
                        </div>
                    </div>
                </div>
                <!-- Button Add More -->
                <input type="button" class="button button-primary button-large resume-add-more" value="Add More">
            </div>

        </div>
    <?php
	}

	/**
	 * Generate Media
	 */
	public function engo_media_html() {

		if ( ! $this->is_support( $this->media['type'] ) ) {
			return; }
		wp_nonce_field( $this->media['type'] . '_save', $this->media['type'] . '_nonce' );
		?>
        <div class="engo-media" media-name="<?php echo esc_attr( $this->media['type'] ); ?>">
            <div class="engo-media-select">
                <div class="content clearfix">
                    <?php
					$default_types = array(
						'feature' => 'As Feature Image',
						'video' => 'Video',
						'gallery' => 'Gallery',
						'slider' => 'Slider',
						'audio' => 'Audio'
					);
					$screen = get_current_screen();
					$types = apply_filters( 'engo_media_post_type_' . $screen->post_type, $default_types );
					$media_type = $this->get_custom_fields( 'media_type', array( 'media_type' => 'feature' ) );
					?>
                    <select name="<?php echo esc_attr( $this->media['type'] ); ?>[media_type]">
                        <?php foreach ( $types as $value => $name ) :   ?>
                            <option
                                value="<?php print $value; ?>" <?php selected( $media_type, $value ); ?>><?php echo wp_unslash( $name ); ?></option>
                        <?php endforeach; ?>

                    </select>
                </div>
            </div>
            <div class="engo-media-quote" <?php if ( $media_type != 'quote' ) :   ?>style="display: none"<?php endif; ?>>
                <div class="content clearfix">
                    <?php
					$quote = $this->get_custom_fields( 'quote', array( 'quote' => array( 'text' => '', 'source' => '' ) ) );
					?>
                    <div class="engo-media-quote-text">
                        <label>Quote</label>
                        <textarea
                            name="<?php echo esc_attr( $this->media['type'] ) . '[quote][text]'; ?>"><?php echo esc_textarea( $quote['text'] ); ?></textarea>
                    </div>
                    <div class="engo-media-quote-source">
                        <label>Source</label>
                        <input type="text" name="<?php echo esc_attr( $this->media['type'] ) . '[quote][source]'; ?>"
                               value="<?php echo esc_attr( $quote['source'] ); ?>">
                    </div>
                </div>
            </div>
            <div class="engo-media-link" <?php if ( $media_type != 'link' ) :   ?>style="display: none"<?php endif; ?>>
                <?php
				$link = $this->get_custom_fields( 'link', array( 'link' => array( 'title' => '', 'url' => '#', 'anchor' => '' ) ) );
				?>
                <div class="content clearfix">
                    <div class="engo-media-link-title">
                        <label>Title</label>
                        <input type="text" name="<?php echo esc_attr( $this->media['type'] ) . '[link][title]'; ?>"
                               value="<?php echo esc_attr( $link['title'] ); ?>">
                    </div>
                    <div class="engo-media-link-url">
                        <label>Url</label>
                        <input type="text" name="<?php echo esc_attr( $this->media['type'] ) . '[link][url]'; ?>"
                               value="<?php echo esc_url( $link['url'] ); ?>">
                    </div>
                    <div class="engo-media-link-anchor-text">
                        <label>Anchor Text</label>
                        <input type="text" name="<?php echo esc_attr( $this->media['type'] ) . '[link][anchor]'; ?>"
                               value="<?php echo esc_attr( $link['anchor'] ); ?>">
                    </div>
                </div>
            </div>
            <div class="engo-media-audio" <?php if ( $media_type != 'audio' ) :   ?>style="display: none"<?php endif; ?>>
                <div class="content clearfix">
                    <?php
					$audio = $this->get_custom_fields( 'audio', array( 'audio' => array( 'link' => '', 'auto_play' => 'true' ) ) );
					?>
                    <ul>
                        <li>
                            <label>Link</label>
                            <ul>
                                <li><input type="text" value="<?php echo esc_url( $audio['link'] ); ?>"
                                           class="engo-audio-link" id="engo-audio-link"
                                           name="<?php echo esc_attr( $this->media['type'] ) . '[audio][link]'; ?>"></li>
                            </ul>
                        </li>
                        <!-- Default Settings -->
                        <li>
                            <label>Auto Play</label>
                            <ul>
                                <li><input type="radio" <?php checked( $audio['auto_play'], 'true' ); ?> value="true"
                                           class="engo-audio-auto-play" id="On"
                                           name="<?php echo esc_attr( $this->media['type'] ) . '[audio][auto_play]'; ?>"><label
                                        for="On">On</label></li>
                                <li><input type="radio" <?php checked( $audio['auto_play'], 'false' ); ?> value="false"
                                           class="engo-audio-auto-play" id="Off"
                                           name="<?php echo esc_attr( $this->media['type'] ) . '[audio][auto_play]'; ?>"><label
                                        for="Off">Off</label></li>

                            </ul>
                        </li>
                        <li>
                            <label>Live Preview
                                <small>(your latest track)</small>
                            </label>
                            <script src="//connect.soundcloud.com/sdk.js"></script>
                            <div class="engo-audio-preview">
                                <?php if ( isset( $audio['link'] ) && ! empty( $audio['link'] ) ) :   ?>

                                    <?php
									if ( preg_match( '/\/sets\//i', $audio['link'] ) || preg_match( '/\/sets\//i', $audio['link'] ) ) {
										$maxheight = '450px'; } else {
										$maxheight = '166px'; }
									?>
                                    <div id="soundcloud-preview"></div>
                                    <script type="text/JavaScript">
                                        SC.oEmbed("<?php echo esc_url( $audio['link'] ); ?>", {
                                            color: "ff0066",
                                            auto_play: <?php print $audio['auto_play']; ?>,
                                            maxheight: "<?php echo esc_attr( $maxheight ); ?>"
                                        }, document.getElementById("soundcloud-preview"));
                                    </script>
                                <?php endif; ?>
                            </div>
                        </li>
                    </ul>

                </div>
            </div>
            <div class="engo-media-gallery" <?php if ( $media_type != 'gallery' ) :   ?>style="display: none"<?php endif; ?>>
                <div class="content clearfix">

                    <?php
					$gallery = $this->get_custom_fields( 'gallery', array() );
					if ( is_array( $gallery ) ) {
						foreach ( $gallery as $img ) {
							echo '
                            <div class="item">
                                <img src="' . esc_url( $img ) . "\"><input type=\"hidden\" name=\"{$this->media['type']}[gallery][]\" value=\"" . esc_url( $img ) . '">
                                <span class="dashicons dashicons-no-alt del-image"></span>
                            </div>'; }
					} else {

						echo '<div class="image-none ">
                                <img src="' . ENGO_ROOT_URL . 'asset/images/image-none.png">
                            </div>';
					}
					?>
                </div>

                <div class="add-image"><input data-filter="gallery" type="button"
                                              class="button button-primary button-large media-add-gallery"
                                              value="Add Image"></div>
                <br>
            </div>
            <div class="engo-media-slider" <?php if ( $media_type != 'slider' ) :   ?>style="display: none"<?php endif; ?>>
                <div class="content clearfix">
                    <?php
					$slider = $this->get_custom_fields( 'slider', array() );
					if ( is_array( $slider ) ) {
						foreach ( $slider as $img ) {
							echo '
                            <div class="item">
                                <img src="' . esc_url( $img ) . "\"><input type=\"hidden\" name=\"{$this->media['type']}[slider][]\" value=\"" . esc_url( $img ) . '">
                                <span class="dashicons dashicons-no-alt del-image"></span>
                            </div>'; }
					} else {

						echo '<div class="image-none ">
                                <img src="' . ENGO_ROOT_URL . 'asset/images/image-none.png">
                            </div>';
					}
					?>
                </div>

                <div class="add-image"><input data-filter="slider" type="button"
                                              class="button button-primary button-large media-add-slider"
                                              value="Add Image"></div>
                <br>
            </div>
            <div class="engo-media-video" <?php if ( $media_type != 'video' ) :   ?>style="display: none"<?php endif; ?>>
                <div class="content clearfix">
                    <?php
					$videos = $this->get_custom_fields( 'videos', array() );
					if ( is_array( $videos ) ) {
						foreach ( $videos as $video ) {
							$v = (array) json_decode( $video );
							echo "<div class=\"item\">
                                <img src='" . esc_url( $v['image'] ) . "'>
                                <input type=\"hidden\" name=\"{$this->media['type']}[videos][]\" value='{$video}'>
                                <div class=\"dashicons dashicons-video-alt3 pattern\"></div>
                                <span class=\"dashicons dashicons-no-alt del-image\"></span>
                            </div>";
						}
					} else {
						echo '<div class="item video-none">
                                <img src="' . ENGO_ROOT_URL . 'asset/images/video-none.png">
                            </div>';
					}
					?>
                </div>

                <div class="add-video">
                    <input class="engo-new-video-url medium" type="text" placeholder="Enter Youtube or Vimeo Url">
                    <input type="button" class="button button-primary button-large media-add-video" value="Add Video">

                    <p<?php _e( 'Note:', 'lotus' ); ?></p>
                    <p><?php _e( 'Vimeo url like: <strong> http://vimeo.com/27260633</strong>', 'lotus' ); ?></p>

                    <p><?php _e( 'Youtube url like: <strong> https://www.youtube.com/watch?v=KV2ssT8lzj8</strong>', 'lotus' ); ?></p>
                </div>
            </div>
        </div>

    <?php
	}

	/**
	 * Save meta data
	 * @param $post_id
	 * @param $post
	 */
	public function meta_save($post_id, $post) {

		if ( ! is_admin() ) {
			return; }
		$reset_values = array(
			'engo_skill' => array( 'skills' => '' ),
			'engo_resume' => array( 'resumes' => '', 'resume_url' => '' ),
			'engo_funfact' => array( 'funfacts' => '' ),
			'engo_feature' => array( 'features' => '' ),
			'engo_offer' => array( 'offer' => '' ),
			'engo_pricing' => array( 'pricing' => '' ),
			'engo_format' => array( 'format' => 'standard' ),
		);
		foreach ( $this->total as $i ) {
			if ( $this->is_support( $i['type'] ) ) {
				if ( isset( $_POST[$i['type']] ) ) {
					$data = wp_parse_args( $_POST[$i['type']], array() );
					if ( $i['type'] == 'engo_resume' && ! isset( $_POST[$i['type']]['resumes'] ) && empty( $_POST[$i['type']]['resume_url'] ) ) {
						$data = $reset_values[$i['type']]; }
					if ( $i['type'] == 'engo_offer' && ! isset( $_POST[$i['type']]['offer'] ) && empty( $_POST[$i['type']]['offer_price'] ) ) {
						$data = $reset_values[$i['type']]; }

					if ( $i['type'] == 'engo_pricing' && ! isset( $_POST[$i['type']]['pricing'] ) ) {
						$data = $reset_values[$i['type']]; }
					if ( $i['type'] == 'engo_format' && ! isset( $_POST[$i['type']]['format'] ) ) {
						$data = $reset_values[$i['type']]; }

					if ( $i['type'] == 'engo_offer' && isset( $_POST[$i['type']]['offer'] ) ) {
						$data = $this->array_remove_empty( $data );
					}
				} else {
					$data = isset( $reset_values[$i['type']] ) ? $reset_values[$i['type']] : array();
				}
				$this->save_custom_fields( $data, $i['type'] . '_save', $i['type'] . '_nonce', $post );
			}
		}
	}

	/**
	 * Remove empty element in deep array
	 * @param $haystack
	 *
	 * @return mixed
	 */
	public function array_remove_empty($haystack) {

		foreach ( $haystack as $key => $value ) {
			if ( is_array( $value ) ) {
				$haystack[$key] = $this->array_remove_empty( $haystack[$key] );
			}

			if ( empty( $haystack[$key] ) ) {
				unset( $haystack[$key] );
			}
		}

		return $haystack;
	}

}
