<?php

Class ENGO_Created_widget {

    var $paths = array();
    var $sidebars = array();
    var $stored = "";

    public function __construct() {
        add_action('load-widgets.php', array(&$this, 'load_assets'), 5);

        $this->paths['css'] = ENGO_WIDGET_AUTO . "/asset/css/";
        $this->paths['js'] = ENGO_WIDGET_AUTO . "/asset/js/";
        $this->title = __('New Sidebar', 'lotus');
        $this->stored = 'engo_sidebars';
        add_action('widgets_init', array(&$this, 'register_custom_sidebars'), 1000);
        add_action('wp_ajax_engo_ajax_delete_custom_sidebar', array(&$this, 'engo_delete_sidebar_area'), 1000);
    }

    public function file_create_widget() {
        include ENGO_WIDGET_ROOT . '/lib/controller/created_widget.php';
    }

    //load backend css, js and add hooks to the widget page
    public function load_assets() {
        add_action('admin_print_scripts', array(&$this, 'engo_template_add_widget_field'));
        add_action('load-widgets.php', array(&$this, 'engo_add_sidebar_area'), 100);

        wp_register_script('engo_sidebar', $this->paths['js'] . 'engo_sidebar.js', array( 'jquery' ));
        wp_enqueue_script('engo_sidebar');
        wp_register_style('engo_sidebar', $this->paths['css'] . 'engo_sidebar.css');
        wp_enqueue_style('engo_sidebar');
    }

    public function engo_template_add_widget_field() {
        $nonce = wp_create_nonce('engo-delete-custom-sidebar-nonce');
        $nonce = '<input type="hidden" name="engo-delete-custom-sidebar-nonce" value="' . $nonce . '" />';

        echo "\n<script type='text/html' id='engo-tmpl-add-widget'>";
        echo "\n  <form class='engo-add-widget' action='' method='POST'>";
        echo "\n  <h3>" . $this->title . "</h3>";
        echo "\n    <span class='engo_style_wrap'><input type='text' value='' placeholder = '" . __('Enter sidebar name', 'lotus') . "' name='add_sidebar' /></span>";
        echo "\n    <input class='button-primary' type='submit' value='" . __('Create New', 'lotus') . "' />";
        echo "\n    " . $nonce;
        echo "\n  </form>";
        echo "\n</script>\n";
    }

    function engo_add_sidebar_area() {
        if (!empty($_POST['add_sidebar'])) {

            $this->sidebars = get_option($this->stored);
            $name = $this->engo_get_name($_POST['add_sidebar']);
            if (empty($this->sidebars)) {
                $this->sidebars = array($name);
            } else {
                $this->sidebars = array_merge($this->sidebars, array($name));
            }
            update_option($this->stored, $this->sidebars);
            wp_redirect(admin_url('widgets.php'));
            die();
        }
    }

    //register custom sidebar areas
    function register_custom_sidebars() {

        if (empty($this->sidebars))
            $this->sidebars = get_option($this->stored);
        $args = array(
            'before_widget' => '<div id="%1$s" class="widget clearfix %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widgettitle">',
            'after_title' => '</h3>'
        );

        $args = apply_filters('engo_custom_widget_args', $args);

        if (is_array($this->sidebars)) {
            foreach ($this->sidebars as $sidebar) {
                if ($sidebar != "") {
                    $args['name'] = $sidebar;
                    $args['id'] = strtolower(str_replace(" ", "-", $sidebar));
                    $args['class'] = 'engo-custom';
                    register_sidebar($args);
                }
            }
        }
    }

    //delete a sidebar area from the database
    function engo_delete_sidebar_area() {
        check_ajax_referer('engo-delete-custom-sidebar-nonce');

        if (!empty($_POST['name'])) {
            $name = stripslashes($_POST['name']);
            $this->sidebars = get_option($this->stored);

            if (($key = array_search($name, $this->sidebars)) !== false) {
                unset($this->sidebars[$key]);
                update_option($this->stored, $this->sidebars);
            }
        }
        die();
    }

    //checks the user submitted name and makes sure that there are no colitions
    function engo_get_name($name) {
        if (empty($GLOBALS['wp_registered_sidebars']))
            return $name;

        $taken = array();
        foreach ($GLOBALS['wp_registered_sidebars'] as $sidebar) {
            $taken[] = $sidebar['name'];
        }

        if (empty($this->sidebars))
            $this->sidebars = array();
        $taken = array_merge($taken, $this->sidebars);

        if (in_array($name, $taken)) {
            $counter = substr($name, -1);
            $new_name = "";

            if (!is_numeric($counter)) {
                $new_name = $name . " 1";
            } else {
                $new_name = substr($name, 0, -1) . ((int) $counter + 1);
            }

            $name = $this->engo_get_name($new_name);
        }

        return $name;
    }

}
