<?php


class ENGO_Tax_Meta {

    protected $layout;
    protected $style;
    protected $masonry_col;
    protected $path = 'config/tax-meta/';

    public function __construct() {
        $this->layout = array(
            'left' => 'Left',
            'right' => 'Right',
            'no' => 'None'
        );

        $taxes = array( 'category', 'post_tag' );
        foreach ($taxes as $tax) {
            add_action($tax . '_edit_form', array($this, 'render'), 100, 2);
        }
        add_action('edit_term', array($this, 'save_meta_data_taxonomy'), 10, 2);
        add_action('delete_term', array($this, 'delete_meta_data_taxonomy'), 10, 2);
        add_filter('get_term', array($this, 'loading_term_meta_data'), 10, 2);
        add_filter('get_terms', array($this, 'loading_terms_meta_data'), 10, 2);

        add_action('admin_enqueue_scripts', array($this, 'load_script'));
    }

    public function load_script() {
        wp_register_script('engo-js-tax-meta', trailingslashit(get_template_directory_uri()) . $this->path . 'js/script.js');
        wp_enqueue_script('engo-js-tax-meta');
        wp_register_style('engo-tax-meta', trailingslashit(get_template_directory_uri()) . $this->path . 'css/style.css');
        wp_enqueue_style('engo-tax-meta');
    }

    public function save_meta_data_taxonomy($term_id, $tt_id) {
        if (defined('DOING_AJAX') && DOING_AJAX)
            return;

        $data = (array) get_option('engo_tax_meta');

        $data[$term_id] = isset($_POST['engo_tax_meta']) ? (array) $_POST['engo_tax_meta'] : array();

        update_option('engo_tax_meta', $data);
    }

    public function delete_meta_data_taxonomy($term_id, $tt_id) {
        $data = (array) get_option('engo_tax_meta');

        unset($data[$term_id]);

        update_option('engo_tax_meta', (array) $data);
    }

    public function loading_term_meta_data($term, $taxonomy) {
        if (!is_object($term))
            return $term;

        $data = get_option('engo_tax_meta');
        $term_meta_data = isset($data[$term->term_id]) ? $data[$term->term_id] : array();
        $term->meta_data = wp_parse_args($term_meta_data, apply_filters('engo_meta_data_defaults', array(
            'layout' => 'default',
            'sidebar_id' => '0',
        )));

        foreach ($term->meta_data as $field => $value)
            $term->meta_data[$field] = apply_filters('engo_term_meta_data' . $field, stripslashes(wp_kses_decode_entities($value)), $term, $taxonomy);

        $term->meta_data = apply_filters('engo_term_meta_data', $term->meta_data, $term, $taxonomy);

        return $term;
    }

    public function loading_terms_meta_data(array $terms, $taxonomy) {
        foreach ($terms as $term)
            $term = $this->loading_term_meta_data($term, $taxonomy);
        return $terms;
    }

    public function render($tag, $taxonomy) {
        global $wp_registered_sidebars;
        $sidebar_list = array_merge( array( '0' => array( 'name' => __( 'As Theme Option', 'lotus' ) ) ), $wp_registered_sidebars );
        $tax = get_taxonomy($taxonomy);
        $meta_data = $tag->meta_data;

        ?>

            <h2><?php echo esc_html($tax->labels->singular_name) . ' ' . __('Layout Settings', 'lotus'); ?></h2>

            <table class="form-table">
                <tr class="form-field">
                    <th scope="row"><?php _e('Choose Layout', 'lotus'); ?></th>
                    <td>
                        <p>
                            <label for="engo-meta-layout-default-field" class="default">
                                <input type="radio" <?php checked($meta_data['layout'], "default"); ?> value="default" id="engo-meta-layout-default-field" class="engo-meta-default-layout"><?php _e('Default Layout set in theme option', 'lotus'); ?>
                            </label>
                        <p>
                        <div class="md-layout-choose">
                            <ul class="clearfix" id="engo-meta-list-layout">
                                <?php foreach ($this->layout as $k => $v): ?>
                                    <li>
                                        <a data-name="<?php print $k; ?>" <?php if ($meta_data['layout'] == $k) print 'class="active"'; ?> href="#"><img src="<?php echo trailingslashit(get_template_directory_uri()) . $this->path . '/images/' . $v . '.png'; ?>" alt=""></a>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                            <input type="hidden" value="<?php print $meta_data['layout']; ?>" name="engo_tax_meta[layout]" id="engo-meta-layout-field" />
                        </div>
                    </td>
                </tr>
                <tr class="form-field">
                    <th><label for="engo-meta-sidebar-id"><?php _e('Sidebar choose?', 'lotus'); ?></label></th>
                    <td>
                        <select id="engo-meta-sidebar-id" name="engo_tax_meta[sidebar_id]">
                            <?php foreach ($sidebar_list as $k => $v) : ?>
                                <option value="<?php echo esc_attr($k); ?>" <?php selected($k, isset($meta_data['sidebar_id']) ? $meta_data['sidebar_id'] : '0') ?>><?php echo esc_html($v['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </td>
                </tr>
            </table>

        <?php
    }

    public static function get_meta($term_id, $field) {
        $engo_tax_meta = get_option('engo_tax_meta') ? (array)get_option('engo_tax_meta') : array();
        if (!isset($engo_tax_meta[$term_id])) {
            return false;
        }
        if (!isset($engo_tax_meta[$term_id][$field])) {
            return false;
        }
        return $engo_tax_meta[$term_id][$field];
    }

}

new ENGO_Tax_Meta();