<?php
/**
 * Custom Config Visual Composer
 */

if (class_exists('Vc_Manager')){

	// Custom Template Shortcode Directory.
	$dir = get_template_directory() . '/engo_shortcode/template';
	vc_set_shortcodes_templates_dir( $dir );

	vc_disable_frontend();

	// Custom class element.
	function engo_custom_css_classes( $class_string, $tag ) {
		if ( $tag == 'vc_column_inner' ) {
			$class_string = preg_replace( '/vc_col-sm-(\d{1,2})/', 'vc_col-xs-$1', $class_string );
		}
		return $class_string;
	}
	add_filter( 'vc_shortcodes_css_class', 'engo_custom_css_classes', 10, 2 );

	class engo_buider {
		public function __construct() {
			$this->path['shortcode'] = '/shortcode';
			$this->path['params'] = '/params';
			$this->path['template'] = '/template';
			add_filter('engo_load_builder_shortcode', array($this, 'engo_load_builder_shortcode'));
			add_filter('engo_load_param_file', array($this, 'engo_load_param_file'));
			add_filter('engo_load_template_file', array($this, 'engo_load_template_file'));
			$this->load_shortcode_file();
			$this->load_class();
			$this->load_params_file();
			//$this->load_template_file();
			// add_action('add_meta_boxes', array($this, 'add_meta_box'));
			add_action('save_post', array($this, 'save_meta'));
		}

		public function engo_load_builder_shortcode($path) {
			$path = array(get_template_directory() . '/engo_shortcode/shortcode/');
			return $path;
		}

		public function engo_load_param_file($path) {
			$path = array(get_template_directory() . '/engo_shortcode/params/');
			return $path;
		}

		public function engo_load_template_file($path) {
			$path = array(get_template_directory() . '/engo_shortcode/template/');
			return $path;
		}

		public function load_params_file() {
			$elements = apply_filters('engo_load_param_file', $this->path['params']);
			foreach ($elements as $key ) {
				foreach (glob($key.'*.php') as $file) {
					require_once($file);
				}
			}
		}

		public function load_template_file() {
			$elements = apply_filters('engo_load_template_file', $this->path['template']);
			foreach ($elements as $key ) {
				foreach (glob($key.'*.php') as $file) {
					require_once($file);
				}
			}
		}

		public function load_shortcode_file() {

			include_once( get_template_directory() . '/engo_shortcode/abstract-shortcode.php');
			$elements = apply_filters('engo_load_builder_shortcode', $this->path['shortcode']);
			foreach ($elements as $key ) {
				foreach (glob($key.'*.php') as $file) {
					require_once($file);
				}
			}
		}

		public function load_class() {
			foreach(get_declared_classes() as $class) {
				if(is_subclass_of($class, 'engo_shortcode')) {
					new $class;
				}
			}
		}

		public function add_meta_box() {
			add_meta_box('engo_menu', __('Setting Menu For This Page', 'lotus'), array($this, 'menu_meta_box'), 'page', 'side', 'high');
		}

		public function menu_meta_box($post) {
			wp_nonce_field( 'engo_menu_page', 'engo_menu_page_nonce' );
			$menu = get_post_meta($post->ID, '_engo_menu', true);
			?>
			<div class="engo-setting-menu">
				<label><?php _e("Choose menu nav", 'lotus')?></label>
				<select name="_engo_menu[nav]">
					<option value=""><?php _e("Default", 'lotus'); ?></option>
					<?php
					if(!empty($menu_nav) && !empty($menu["style"]))
					{
						foreach($menu_nav as $item)
						{
							if(is_object($item))
							{
								?><option value="<?php echo esc_attr($item->slug);?>" <?php selected($menu["nav"], $item->slug) ?>><?php echo esc_attr($item->name); ?></option><?php
							}
						}
					}
					?>
				</select>
			</div>
			<?php
		}

		public function save_meta($post_id) {
			if ( ! isset( $_POST['engo_menu_page_nonce'] ) ) {
				return;
			}
			if ( ! wp_verify_nonce( $_POST['engo_menu_page_nonce'], 'engo_menu_page' ) ) {
				return;
			}
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}
			if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

				if ( ! current_user_can( 'edit_page', $post_id ) ) {
					return;
				}

			} else {

				if ( ! current_user_can( 'edit_post', $post_id ) ) {
					return;
				}
			}
			if(isset($_POST['_engo_menu']))
			{
				$value = stripslashes_deep($_POST['_engo_menu']);
				update_post_meta($post_id, '_engo_menu', $value);
			}
		}

	}

	new engo_buider();


	if ( class_exists( 'WPBMap' ) ) {

		// Add subtitle to tab shortcode
		add_action( 'init', 'engo_add_tab_param' );
		function engo_add_tab_param() {
			$engo_sc = WPBMap::getShortCode( 'vc_tab' );
			$engo_param = $engo_sc['params'];

			foreach ( $engo_param as $k => $v ) {
				if ( $v['param_name'] == 'title' ) {
					$engo_param[$k]['weight'] = 3;
				} elseif ( $v['param_name'] == 'tab_id' ) {
					$engo_param[$k]['weight'] = 1;
				}
			}

			$engo_sc['params'] = $engo_param;

			unset( $engo_sc['base'] );

			vc_map_update( 'vc_tab', $engo_sc );


			$attributes = array(
				'type' => 'textfield',
				'heading' => "Subtitle",
				'param_name' => 'subtitle',
				'weight'	=> 2,
			);
			vc_add_param( 'vc_tab', $attributes );
		}


		add_action( 'init', 'engo_add_tab_param_4_6' );
		function engo_add_tab_param_4_6() {
			// Change param weight
			$engo_sc = WPBMap::getShortCode( 'vc_tta_section' );
			$engo_param = $engo_sc['params'];

			if ( ! $engo_param ) return;

			foreach ( $engo_param as $k => $v ) {
				if ( $v['param_name'] == 'title' ) {
					$engo_param[$k]['weight'] = 3;
				}
			}

			$engo_sc['params'] = $engo_param;

			unset( $engo_sc['base'] );

			vc_map_update( 'vc_tta_section', $engo_sc );

			// add new param
			$attributes = array(
				'type' => 'textfield',
				'heading' => "Subtitle",
				'param_name' => 'subtitle',
				'weight'	=> 2,
			);
			vc_add_param( 'vc_tta_section', $attributes );
		}


		// Tab title output
		function engo_tab_title_output( $atts, $content, $obj, $sectionClass, $shortcode ) {
			$isPageEditabe = vc_is_page_editable();

			// $sectionClass = $this->sectionClass;
			// $sectionClass = $args['section_class'];

			$html = array();
			$html[] = '<div class="vc_tta-tabs-container">';
			$html[] = '<ul class="vc_tta-tabs-list">';
			if ( ! $isPageEditabe ) {
				$strict_bounds = ( 'vc_tta_tabs' === $shortcode );
				$active_section = $obj->getActiveSection( $atts, $strict_bounds );

				foreach ( WPBakeryShortCode_VC_Tta_Section::$section_info as $nth => $section ) {
					$classes = array( 'vc_tta-tab' );
					if ( ( $nth + 1 ) === $active_section ) {
						$classes[] = $obj->activeClass;
					}

					$title = '<span class="vc_tta-title-text">' . $section['title'] . '</span>';
					if ( $section['subtitle'] ) {
						$title .= '<span class="subtitle">' . $section['subtitle'] . '</span>';
					}

					if ( 'true' === $section['add_icon'] ) {
						$icon_html = $obj->constructIcon( $section );
						if ( 'left' === $section['i_position'] ) {
							$title = $icon_html . $title;
						} else {
							$title = $title . $icon_html;
						}
					}
					$a_html = '<a href="#' . $section['tab_id'] . '" data-vc-tabs data-vc-container=".vc_tta">' . $title . '</a>';
					$html[] = '<li class="' . implode( ' ', $classes ) . '" data-vc-tab>' . $a_html . '</li>';
				}
			}

			$html[] = '</ul>';
			$html[] = '</div>';

			return implode( '', $html );
		}


		function engo_icon_param_scripts() {
			// wp_enqueue_style( 'engo-lotus-font', get_template_directory_uri() . '/assets/css/lib/font-lotusicon.css' );
			// wp_enqueue_style( 'engo-dialog', get_template_directory_uri() . '/engo_shortcode/assets/iconlist/engo-dialog.css', false, false );
			wp_enqueue_script( "jquery-list", ENGO_JS_URL . "lib/list.min.js", array(), '0' );
			wp_enqueue_script( 'engo-icon-js', get_template_directory_uri() . '/engo_shortcode/assets/iconlist/Engo.js', array(), null, true );
			wp_enqueue_script( 'engo_dialog-js', get_template_directory_uri() . '/engo_shortcode/assets/iconlist/Engo_dialog.js', array(), null, true );

			wp_localize_script( 'jquery', 'Engo', array(
				'themeurl'	=> get_template_directory_uri(),
			) );
		}


		function engo_icon_param() {
			// enqueue font css
			add_action( 'admin_enqueue_scripts', 'engo_icon_param_scripts' );

			// Change param
			$engo_sc = WPBMap::getShortCode( 'vc_icon' );
			$engo_param = $engo_sc['params'];

			// Add to dropdown
			$engo_param[0]['value'][__( 'Lotus icon', 'lotus' )] = 'lotus';

			// Add icon picker field
			$field = array(
				array(
					'type'	=> 'iconpicker',
					'heading'	=> __( 'Icon', 'lotus' ),
					'param_name'	=> 'icon_lotus',
					'settings'	=> array(
						'emptyIcon'	=> false,
						'type'	=> 'lotus',
						'iconsPerPage'	=> 4000,
					),
					'dependency'	=> array(
						'element'	=> 'type',
						'value'	=> 'lotus',
					)
				)
			);
			array_splice( $engo_param, 6, 0, $field );

			$engo_sc['params'] = $engo_param;

			unset( $engo_sc['base'] );

			vc_map_update( 'vc_icon', $engo_sc );
		}
		add_action( 'init', 'engo_icon_param' );


		function lotus_vc_iconpicker_type( $icons ) {
			$lotus_icons = array(
				array( 'lotus-icon-person' => __( 'Person', 'lotus' ) ),
				array( 'lotus-icon-quote-left' => __( 'Quote left', 'lotus' ) ),
				array( 'lotus-icon-breakfast' => __( 'Breakfast', 'lotus' ) ),
				array( 'lotus-icon-decor' => __( 'Decor', 'lotus' ) ),
				array( 'lotus-icon-bed' => __( 'Bed', 'lotus' ) ),
				array( 'lotus-icon-telephone' => __( 'Telephone', 'lotus' ) ),
				array( 'lotus-icon-hangers' => __( 'Hangers', 'lotus' ) ),
				array( 'lotus-icon-phone' => __( 'Phone', 'lotus' ) ),
				array( 'lotus-icon-ocenview' => __( 'Ocenview', 'lotus' ) ),
				array( 'lotus-icon-calendar' => __( 'Calendar', 'lotus' ) ),
				array( 'lotus-icon-cart' => __( 'Cart', 'lotus' ) ),
				array( 'lotus-icon-wifi' => __( 'Wifi', 'lotus' ) ),
				array( 'lotus-icon-arrow' => __( 'Arrow', 'lotus' ) ),
				array( 'lotus-icon-air-conditioner' => __( 'Air conditioner', 'lotus' ) ),
				array( 'lotus-icon-cable' => __( 'Cable', 'lotus' ) ),
				array( 'lotus-icon-luxury' => __( 'Luxury', 'lotus' ) ),
				array( 'lotus-icon-location' => __( 'Location', 'lotus' ) ),
				array( 'lotus-icon-size' => __( 'Size', 'lotus' ) ),
				array( 'lotus-icon-cloud' => __( 'Cloud', 'lotus' ) ),
				array( 'lotus-icon-view' => __( 'View', 'lotus' ) ),
				array( 'lotus-icon-time' => __( 'Time', 'lotus' ) ),
				array( 'lotus-icon-bar' => __( 'Bar', 'lotus' ) ),
				array( 'lotus-icon-microphone' => __( 'Microphone', 'lotus' ) ),
				array( 'lotus-icon-media-play' => __( 'Media play', 'lotus' ) ),
				array( 'lotus-icon-down-arrow' => __( 'Arrow down', 'lotus' ) ),
				array( 'lotus-icon-cooker-hood' => __( 'Cooker hood', 'lotus' ) ),
				array( 'lotus-icon-left-arrow' => __( 'Arrow left', 'lotus' ) ),
				array( 'lotus-icon-right-arrow' => __( 'Arrow right', 'lotus' ) ),
			);

			return array_merge( $icons, $lotus_icons );
		}
		add_filter( 'vc_iconpicker-type-lotus', 'lotus_vc_iconpicker_type' );


		// Add font size to text block
		add_action( 'init', 'engo_add_textblock_param' );
		function engo_add_textblock_param() {

			$engo_sc = WPBMap::getShortCode( 'vc_column_text' );
			$engo_param = $engo_sc['params'];

			$size_value = array(
				__( 'Default', 'lotus' )	=> 0,
			);
			for ( $i = 10; $i <= 50; $i++ ) {
				$size_value[$i . 'px'] = $i;
			}

			$field = array(
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Text size', 'lotus' ),
					'param_name'	=> 'size',
					'value'	=> $size_value,
				),
			);
			array_splice( $engo_param, 1, 0, $field );


			$engo_sc['params'] = $engo_param;

			unset( $engo_sc['base'] );

			vc_map_update( 'vc_column_text', $engo_sc );

		}


		// Add some option to param: Lotus style, Transparent
		add_action( 'init', 'engo_add_tab_param_option' );
		function engo_add_tab_param_option() {
			// Change param weight
			$engo_sc = WPBMap::getShortCode( 'vc_tta_tabs' );
			$engo_param = $engo_sc['params'];

			if ( ! $engo_param ) return;

			// var_dump( $engo_param );

			$engo_param[1][ 'value' ][ __( 'Lotus', 'lotus' ) ] = 'lotus';
			$engo_param[3][ 'value' ][ __( 'Transparent', 'lotus' ) ] = 'transparent';

			// var_dump( $engo_param );
			$engo_sc['params'] = $engo_param;

			unset( $engo_sc['base'] );

			vc_map_update( 'vc_tta_tabs', $engo_sc );

		}

	}

}

add_action( 'init', function() {
} );
