<?php
/**
 * Engo button shortcode
 *
 * @package Lotus
 */

/**
 * Class ENGO_Button_Shortcode
 */
class ENGO_Button_Shortcode extends engo_shortcode {

	public function __construct() {
		$this->custom_shortcode( 'engo_button', array( $this, 'engo_render_html' ) );
		add_action( 'vc_before_init', array( $this, 'engo_vc_shortcode' ) );
	}


	public function engo_vc_shortcode() {
		vc_map( array(
			'name'	      => __( 'Engo Button', 'lotus' ),
			'base'	      => 'engo_button',
			'category'	  => __( 'Engo shortcode', 'lotus' ),
			'icon'	      => $this->icon( 'shortcode.png' ),
			'description' => __( 'Display button.', 'lotus' ),
			'params'	  => array(
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Button Label', 'lotus' ),
					'param_name'  => 'button_content',
					'holder'      => 'div',
					'description' => 'This is the text that appears on your button.',
				),
				array(
					'type'        => 'vc_link',
					'heading'     => __( 'Button Link', 'lotus' ),
					'param_name'  => 'link',
					'description' => 'Where should your button link to?',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Button Style', 'lotus' ),
					'param_name'  => 'style',
					'value'       => array(
						__( 'Background color (Default)', 'lotus' ) => 'default',
						__( 'Outline', 'lotus' )                    => 'outline',
					),
					'description' => 'Set style to your button.',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Button Size', 'lotus' ),
					'param_name'  => 'size',
					'value'       => array(
						__( 'Normal (Default)', 'lotus' ) => 'normal',
						__( 'Medium', 'lotus' )           => 'medium',
						__( 'Large', 'lotus' )            => 'large',
					),
					'description' => 'Set dimension to your button.',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Button Alignment', 'lotus' ),
					'param_name'  => 'align',
					'value'       => array(
						__( 'Inline', 'lotus' ) => 'inline',
						__( 'Left', 'lotus' )   => 'left',
						__( 'Right', 'lotus' )  => 'right',
						__( 'Center', 'lotus' ) => 'center',
					),
					'description' => 'Align your button.',
				),
				array(
					'type'        => 'checkbox',
					'heading'     => __( 'Set Fullwidth Button', 'lotus' ),
					'param_name'  => 'fullwidth_btn',
					'dependency'  => array(
						'element' => 'align',
						'value'   => array( 'left', 'right', 'center' ),
					),
					'description' => 'Switch your button to fullwith mode.',
				),
				array(
					'type'        => 'colorpicker',
					'heading'     => __( 'Button Color', 'lotus' ),
					'param_name'  => 'color',
					'description' => 'Display your button with your custom color.',
				),
			),
		) );
	}


	public function engo_render_html( $atts, $content = '' ) {
		extract( shortcode_atts( array(
			'link'	=> '',
			'style'	=> 'default',
			'size'	=> 'normal',
			'align'	=> 'inline',
			'fullwidth_btn'	=> '',
			'color'	=> '',
			'button_content' => '',
		), $atts ) );

		// Link.
		$link_url = '';
		$link_title = '';
		if ( $link ) {
			$link = vc_build_link( $link );

			$link_url = $link['url'];
			$link_title = $link['title'];
		}

		// Style.
		$extra = '';
		$style = in_array( $style, array( 'default', 'outline' ) ) ? $style : 'default';
		if ( 'default' === $style ) {
			$extra .= ' style="background-color:' . $color . ';border-color:' . $color . '"';
		} else {
			$extra .= ' style="color:' . $color . ';border-color:' . $color . ';"';
		}

		// Size.
		$size = in_array( $size, array( 'normal', 'medium', 'large' ) ) ? $size : 'normal';

		$button_class = 'engo-btn';
		$button_class .= ' engo-btn-' . $size;
		$button_class .= ' engo-btn-' . $style;

		if ( $fullwidth_btn ) {
			$button_class .= ' engo-btn-full';
		}

		if ( ! empty( $link[2] ) && $link_url ) {
			$extra .= ' target="_blank"';
		}

		if ( $link_url ) {
			$output = '<a class="' . esc_attr( $button_class ) . '" href="' . esc_url( $link_url ) . '" title="' . esc_attr( $link_title ) . '"' . $extra . '>' . esc_html( $button_content ) . '</a>';
		} else {
			$output = '<button class="' . esc_attr( $button_class ) . '"' . $extra . '>' . esc_html( $button_content ) . '</button>';
		}

		$output = '<div class="engo-btn-container engo-btn-' . esc_attr( $align ) . '">' . $output  . '</div>';

		return $output;
	}
}


if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_ENGO_Button extends WPBakeryShortCode {

	}
}
