<?php
/**
 * Engo catalogue 2 shortcode
 *
 * @package Lotus
 */

/**
 * Class ENGO_Catalogue2_Shortcode
 */
class ENGO_Catalogue2_Shortcode extends engo_shortcode {

	/**
	 * Shortcode name.
	 *
	 * @var string
	 */
	protected $shortcode_name = 'engo_catalogue2';


	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->custom_shortcode( $this->shortcode_name, array( $this, 'engo_render_html' ) );
		add_action( 'vc_before_init', array( $this, 'engo_vc_shortcode' ) );
	}


	/**
	 * Map shortcode.
	 */
	public function engo_vc_shortcode() {
		vc_map( array(
			'name'        => __( 'Engo Catalogue 2', 'lotus' ),
			'base'        => $this->shortcode_name,
			'class'       => '',
			'category'    => __( 'Engo shortcode', 'lotus' ),
			'icon'        => $this->icon( 'shortcode.png' ),
			'description' => __( 'Display food catalogue.', 'lotus' ),
			'params'      => array(
				array(
					'type'       => 'dropdown',
					'heading'    => __( 'Catalogue Style', 'lotus' ),
					'param_name' => 'style',
					'value'      => array(
						__( 'Small thumbnail', 'lotus' )     => 'small',
						__( 'Large thumbnail', 'lotus' )     => 'large',
						__( 'Tabs no thumbnail', 'lotus' )   => 'tabs',
						__( 'Tabs with thumbnail', 'lotus' ) => 'tabs-thumb',
					),
				),
				array(
					'type'       => 'param_group',
					'heading'    => __( 'Catalogues', 'lotus' ),
					'param_name' => 'list',
					'params'     => array(
						array(
							'type'       => 'attach_image',
							'heading'    => __( 'Image', 'lotus' ),
							'param_name' => 'image',
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Title', 'lotus' ),
							'param_name' => 'title',
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Description', 'lotus' ),
							'param_name' => 'desc',
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Price', 'lotus' ),
							'param_name' => 'price',
						),
						array(
							'type'       => 'textfield',
							'heading'    => __( 'Sale price', 'lotus' ),
							'param_name' => 'sale_price',
						),
					),
				),
			),
		) );
	}


	/**
	 * Render shortcode.
	 *
	 * @param  array  $atts    Shortcode attributes.
	 * @param  string $content Content.
	 * @return string
	 */
	public function engo_render_html( $atts, $content = '' ) {
		$atts = shortcode_atts( array(
			'list'	=> '',
			'style'	=> 'small',
		), $atts );

		$list = vc_param_group_parse_atts( $atts['list'] );

		if ( empty( $list ) ) {
			return '';
		}

		switch ( $atts['style'] ) {
			case 'large':
				$item_class = 'large-thumbs';
				break;

			case 'restaurant-tabs':
				$item_class = 'small-thumbs';
				break;

			default:
				$item_class = 'small-thumbs';
		}

		ob_start();
		?>
		<div class="restaurant_content">
			<?php
			foreach ( $list as $item ) {
				$image = isset( $item['image'] ) ? wp_get_attachment_image_src( $item['image'], 'engo-gallery-rectangular' ) : '';
				?>
				<div class="restaurant_item <?php echo esc_attr( $item_class ); ?>">
					<?php if ( 'tabs' != $atts['style'] && $image ) : ?>
						<div class="img">
							<a href="#"><img src="<?php echo esc_url( $image[0] ); ?>" alt=""></a>
						</div>
					<?php endif; ?>

					<div class="text">
						<?php if ( ! empty( $item['title'] ) ) : ?>
							<h2><?php echo esc_html( $item['title'] ); ?></h2>
						<?php endif; ?>

						<?php if ( ! empty( $item['desc'] ) ) : ?>
							<p class="desc"><?php echo nl2br( esc_html( $item['desc'] ) ) ?></p>
						<?php endif; ?>

						<?php if ( ! empty( $item['price'] ) ) : ?>
							<p class="price">
								<?php if ( empty( $item['sale_price'] ) ) : ?>
									<span class="amout"><?php echo esc_html( $item['price'] ); ?></span>
								<?php else : ?>
									<ins><span class="amout"><?php echo esc_html( $item['sale_price'] ); ?></span></ins>
									<del><span class="amout"><?php echo esc_html( $item['price'] ); ?></span></del>
								<?php endif; ?>
							</p>
						<?php endif; ?>
					</div>
				</div>
				<?php
			}
			?>
		</div>
		<?php
		return ob_get_clean();
	}
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_ENGO_Catalogue2_Shortcode extends WPBakeryShortCode {

	}
}
