<?php

class ENGO_Special_Heading extends engo_shortcode {

	public function __construct() {
		$this->custom_shortcode( 'engo_special_heading', array( $this, 'engo_render_html' ) );
		add_action( 'vc_before_init', array( $this, 'engo_vc_shortcode' ) );
	}

	public function engo_vc_shortcode() {
		$size_value = array(
			__( 'Default', 'lotus' )	=> 0,
		);
		for ( $i = 10; $i <= 50; $i++ ) {
			$size_value[$i . 'px'] = $i;
		}

		$pad_value = array();
		for ( $i = 0; $i <= 100; $i++ ) {
			$pad_value[$i . 'px'] = $i;
		}

		vc_map( array(
			'name'	=> __( 'Engo Special Heading', 'lotus' ),
			'base'	=> 'engo_special_heading',
			'category'	=> __( 'Engo shortcode', 'lotus' ),
			'icon'	=> $this->icon('shortcode.png'),
            'description' => __( 'Display special heading', 'lotus' ),
			'params'	=> array(
				array(
					'type'	=> 'textfield',
					'heading'	=> __( 'Heading text', 'lotus' ),
					'param_name'	=> 'heading_text',
					'holder'	=> 'div',
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Heading type', 'lotus' ),
					'param_name'	=> 'type',
					'description' => '',
					'value'	=> array(
						'H1'	=> 'h1',
						'H2'	=> 'h2',
						'H3'	=> 'h3',
						'H4'	=> 'h4',
						'H5'	=> 'h5',
						'H6'	=> 'h6',
					),
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Heading style', 'lotus' ),
					'param_name'	=> 'style',
					'value'	=> array(
						__( 'Center', 'lotus' )	=> 'center',
						__( 'Left', 'lotus' )	=> 'left',
						__( 'Right', 'lotus' )	=> 'right',
					),
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Heading size', 'lotus' ),
					'param_name'	=> 'size',
					'value'	=> $size_value,
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Subheading', 'lotus' ),
					'param_name'	=> 'subheading',
					'value'	=> array(
						__( 'None', 'lotus' )	=> 'none',
						__( 'Display subheading below', 'lotus' )	=> 'below',
						__( 'Display subheading above', 'lotus' )	=> 'above',
					),
				),
				array(
					'type'	=> 'textarea',
					'heading'	=> __( 'Subheading text', 'lotus' ),
					'param_name'	=> 'sub_text',
					'dependency'	=> array(
						'element'	=> 'subheading',
						'value'	=> array( 'below', 'above' ),
					),
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Subheading size', 'lotus' ),
					'param_name'	=> 'sub_size',
					'value'	=> $size_value,
					'dependency'	=> array(
						'element'	=> 'subheading',
						'value'	=> array( 'below', 'above' ),
					),
				),
				array(
					'type'	=> 'dropdown',
					'heading'	=> __( 'Padding bottom', 'lotus' ),
					'param_name'	=> 'pad_bottom',
					'value'	=> $pad_value,
				),
				array(
					'type'	=> 'colorpicker',
					'heading'	=> __( 'Color', 'lotus' ),
					'param_name'	=> 'color',
					'group'	=> __( 'Color', 'lotus' ),
				),
			)
		) );
	}


	public function engo_render_html( $atts, $content = '' ) {
		extract( shortcode_atts( array(
			'heading_text' => '',
			'type'	=> 'h1',
			'style'	=> 'center',
			'size'	=> 0,
			'subheading'	=> 'none',
			'sub_text'	=> '',
			'sub_size'	=> 0,
			'pad_bottom'	=> 0,
			'color'	=> '',
		), $atts ) );
		// text
		$heading =  esc_html($heading_text) ;
		// size
		$size = absint( $size );
		$size_atts = '';
		if ( $size ) {
			$size_atts = ' style="font-size:' . $size . 'px"';
		}

		// tag
		if ( $heading ) {
			$heading = "<{$type}{$size_atts}>{$heading}</{$type}>";
		}

		// subheading
		$subheading = in_array( $subheading, array( 'none', 'below', 'above' ) ) ? $subheading : 'none';
		if ( $subheading != 'none' ) {
			// Subheading size
			$sub_size = absint( $sub_size );
			$sub_size_atts = '';
			if ( $sub_size ) {
				$sub_size_atts = ' style="font-size:' . $sub_size . 'px"';
			}

			// subheading text
			if ( $sub_text ) {
				$sub_head = '<div class="engo-subheading ' . esc_attr( $subheading ) . '"' . $sub_size_atts . '><p>' . esc_html( $sub_text ) . '</p></div>';
			}

			// subheading posision
			if ( $subheading == 'below' ) {
				$output = $heading . $sub_head;
			} else {
				$output = $sub_head . $heading;
			}
		} else {
			$output = $heading;
		}

		// container
		if ( $output ) {
			$contain_style = '';

			// padding
			$pad_bottom = absint( $pad_bottom );
			if ( $pad_bottom ) {
				$contain_style .= 'padding-bottom:' . $pad_bottom . 'px;';
			}

			// Color
			if ( $color ) {
				$contain_style .= 'color:' . $color . ';';
			}

			$contain_atts = '';
			if ( $contain_style ) {
				$contain_atts = ' style="' . esc_attr( $contain_style ) . '"';
			}

			$output = '<div class="engo-special-heading text-' . esc_attr( $style ) . '"' . $contain_atts . '>' . $output . '</div>';
		}

		return $output;
	}

}

if ( class_exists( 'WPBakeryShortCode' ) ) {

	class WPBakeryShortCode_ENGO_Special_Heading extends WPBakeryShortCode {

	}

}
